@@ -23,14 +23,16 @@ import functools
 import inspect
 import sys
 
-from typing import Optional
+from typing import List, Optional
 from typing import Any
 from typing import Callable
 from typing import Tuple
 from typing import get_type_hints
 
 from .command import HypeCommand
+from .command import HypeArgument
 from .parser import HypeParser
+
 from .print import print as _print
 
 from .constants import rule_colors
@@ -70,6 +72,7 @@ class Hype:
     __required_commands = []
     __commands_function = {}
     __registered_args = {}
+    __registered_args_func = {}
 
     def __init__(self):
 
@@ -87,7 +90,7 @@ class Hype:
 
         return command_list
 
-    def echo(self, text: str = "", **options):
+    def echo(self, text: Any, **options):
         """
         A format wrapper for the hype.print. It can print
         text with colors and styles. using the tag [%tagname%][/]
@@ -144,7 +147,7 @@ class Hype:
         name: str = None,
         usage: Optional[str] = None,
         aliases: Optional[Tuple[Any]] = (),
-        help: Optional[str] = "",
+        help: Optional[str] = ""
     ):
 
         """
@@ -187,8 +190,11 @@ class Hype:
 
             _name = name if name else func.__name__
 
+            #: Replace the _ to -
+            _name = _name.replace('_', '-')
+
             #: Set the help of the command
-            _help = help or 'This command accept a positional arguments'
+            _help = help or func.__doc__
 
             #: The signature of the function
             signature = inspect.signature(func)
@@ -199,16 +205,33 @@ class Hype:
             #: Set the params to none dict. It should contain the param of the function
             #: and the type hints of the parameters
             params = []
+            rargs_keys = {}
 
+            for k,v in self.__registered_args_func.items():
+                if k.__name__ == func.__name__:
+                    rargs_keys = v
+                    
+                else:
+                    rargs_keys = {}
+
+                    
             for param in signature.parameters.values():
                 #: The annotation of the function.
                 #: For example: def func(name: str) -> str is the annotaiton
                 annotation = param.annotation
-                
+
+                #: The param name of the function
+                #: For example: def func(name) -> name is the param.
+                param_name = param.name
+
+                #: Replace the _ to - for params
+                param_name = param_name.replace('_', '-')
+
+
                 if param.name in type_hints:
                     annotation = type_hints[param.name]
 
-                if param.name not in self.__registered_args.keys():
+                if param.name not in rargs_keys:
                     required = True if param.default is inspect.Parameter.empty else False
                     default = (
                         param.default
@@ -218,16 +241,16 @@ class Hype:
                     anon = annotation if annotation is not inspect.Parameter.empty else None
 
                     optionparam = ParamOption(
-                        convert_param_to_option(param.name),
+                        convert_param_to_option(param_name),
                         required,
                         default,
                         anon,
-                        param.name,
+                        param.name
                     )
                     params.append(optionparam.to_dict)
 
             self.__commands[_name] = CommandDict(
-                _name, _usage, _help, _aliases, params, func
+                _name, _usage, _help, _aliases, params, func,
             ).to_dict
             self.__commands_function[func] = {"name": _name}
 
@@ -235,7 +258,7 @@ class Hype:
 
         return deco
 
-    def argument(self, name: str, type: Optional[Any] = None):
+    def argument(self, name: str, type: Optional[Any] = None, help: Optional[str] = "This argument accept anything"):
         """
         A argument decorator for registering arguments. 
         Please take note that when you define argument, make sure
@@ -260,13 +283,19 @@ class Hype:
             >>>     app.echo(option)
 
         """
+        name = name
+        help = help
+        type = type 
+        
         def deco(func):
-            self.__registered_args[name] = {'type': type}
+            self.__registered_args_func[func] = {name: {'type': type, 'help': help}}
+            self.__registered_args[name] = {'type': type, 'help': help}
             @functools.wraps(func)
             def wrapper(*args, **kwargs):
-                return func(*args, **kwargs) 
+                return func(*args, **kwargs)
 
             return wrapper
+
         return deco
 
     def exit(self):
@@ -328,18 +357,44 @@ class Hype:
 
         commands = []
         boolean_options = []
-
+        # self.__registered_args_func = {}
         for k in self.__commands.keys():
+            
+            for ak, av in self.__registered_args_func.items(): 
+                for _k in av.keys():
+                    pass
 
-            self.__command_parser = HypeCommand(
-                self.__commands[k]["name"],
-                self.__commands[k]["usage"],
-                self.__commands[k]["aliases"],
-                self.__commands[k]["help"],
-            )
+                if self.__commands[k]['func'].__name__ == ak.__name__:                
+                    self.__command_parser = HypeCommand(
+                        self.__commands[k]["name"],
+                        self.__commands[k]["usage"],
+                        self.__commands[k]["aliases"],
+                        self.__commands[k]["help"],
+                        [HypeArgument(name=_k, help=av[_k]['help'], type=av[_k]['type'])]
+                    )
+                    break
+
+                else:
+                    self.__command_parser = HypeCommand(
+                        self.__commands[k]["name"],
+                        self.__commands[k]["usage"],
+                        self.__commands[k]["aliases"],
+                        self.__commands[k]["help"]
+                    )
+                    break
+                
+            if not self.__registered_args_func:
+                self.__command_parser = HypeCommand(
+                    self.__commands[k]["name"],
+                    self.__commands[k]["usage"],
+                    self.__commands[k]["aliases"],
+                    self.__commands[k]["help"]
+                )
+            
 
             if self.__commands[k]["options"]:
                 for _option in self.__commands[k]["options"]:
+                    
 
                     if _option["required"]:
 
@@ -411,25 +466,36 @@ class Hype:
             self.__command_parser.parser.add_option(
                 i["name"], default=i["default"], type=i["type"], action=i["action"]
             )
-
-        if command_args:
-            for i in range(len(self.__registered_args)):
-                for k in self.__registered_args.keys():
-                    if self.__registered_args[k]['type']:
-                        self.__registered_args[k]['type'](command_args[i])
-                        # del self.__registered_args[k]['type']
-
-                    self.__registered_args[k] = command_args[i]
-
-                params.append(command_args[i])   
-
-        for _k, v in vars(command_opt).items():
-            if (command.name, _k) in self.__required_commands and v == None:
-                parser.error("Option: {} is required.".format(_k))
-                parser.exit()
-
             
-            params.append(v)
+
+
 
         if command.name in self.__commands:
-            self.__commands[command.name]["func"](*params)
+            func = self.__commands[command.name]['func']
+        
+
+            if command_args:
+                # TODO: Check for function registered and return the args
+                # NOTE: Please if you have some time improving this, create a pull req 
+
+                for k, v in self.__registered_args_func.items():
+                    if k.__name__ == func.__name__:
+                        for t in range(len(v)):
+                            for _k in v.keys():
+                                if v[_k]['type']:
+                                    v[_k]['type'](command_args[t])
+                            
+                            params.append(command_args[t])
+                            
+            else:
+                params.append(None)
+
+            
+            for _k, v in vars(command_opt).items():
+                if (command.name, _k) in self.__required_commands and v == None:
+                    parser.error("Option: {} is required.".format(_k))
+                    parser.exit()
+
+                params.append(v)
+
+            func(*params)
